<?php
// Настройки сайта
$system = parse_ini_file(__DIR__."/system.ini", true);
// Система
$sys_array = $system['system'];
// Платежные системы
$pay_array = $system['payment'];
// Модули
$mod_array = $system['modules'];
// Рейтинг
$rat_array = $system['rating'];
// Реклама
$rek_array = $system['rek'];
// Все символы (REGEXP SQL)
define('RS_ALL_CHARS', '.*');
// Отладка
ini_set('error_reporting', $mod_array['debug'] ? E_ALL : 0);
ini_set('display_errors', $mod_array['debug']);
ini_set('display_startup_errors', $mod_array['debug']);
// Подключение к БД
try {
    $connect = new PDO("mysql:host=".$system['db']['db_host'].";dbname=".$system['db']['db_name'].";charset=utf8", $system['db']['db_user'], $system['db']['db_pass']);
} catch (PDOException $e) {
    exit("Подключение не удалось: ".$e->getMessage());
}
// Функции для работы с файлами
require_once(__DIR__."/file_function.php");
// Фильтр данных
require_once(__DIR__."/data_filter.php");
// Постраничная навигация
require_once(__DIR__."/Pagination.php");
// BB-коды
require_once(__DIR__."/bb.php");
// Обработка времени
require_once(__DIR__."/daytime.php");
// Градиент
require_once(__DIR__."/gradient.php");
// SimpleImage
require_once(__DIR__."/SimpleImage.php");
// Mobile Detect
require_once(__DIR__."/Mobile_Detect.php");
// IP посетителя
$ip = $_SERVER['REMOTE_ADDR'] ?? 'unknown';
// Определение реального браузера
$ua = $_SERVER['HTTP_USER_AGENT'] ?? 'unknown';
// Кодировка
mb_internal_encoding('UTF-8');
// Дата и время
date_default_timezone_set('Europe/Moscow');
// Корневая папка
define('ROOT', 'http://'.$_SERVER['HTTP_HOST']);
// Валидность URL
function isSiteAvailable($url) {
    if (filter_var($url, FILTER_VALIDATE_URL)) {
        $init = curl_init($url);
        curl_setopt($init, CURLOPT_CONNECTTIMEOUT, 10);
        curl_setopt($init, CURLOPT_HEADER, true);
        curl_setopt($init, CURLOPT_NOBODY, true);
        curl_setopt($init, CURLOPT_RETURNTRANSFER, true);
        $response = curl_exec($init);
        curl_close($init);
        if ($response)
            $result = 1;
    }
    return $result ?? 0;
}
// Функция отправки почты на email
function mailto($mail, $theme, $text, $str) {
    $adt = "From: ".$str." \n";
    $adt.= "X-sender: < ".$str." >\n";
    $adt.= "Content-Type: text/html; charset=utf-8\n";
    return mail($mail, $theme, $text, $adt);
}
// Транслит
function rus2translit($str) {

    $rus = ['А', 'Б', 'В', 'Г', 'Д', 'Е', 'Ё', 'Ж', 'З', 'И', 'Й', 'К',
                 'Л', 'М', 'Н', 'О', 'П', 'Р', 'С', 'Т', 'У', 'Ф', 'Х', 'Ц',
                 'Ч', 'Ш', 'Щ', 'Ъ', 'Ы', 'Ь', 'Э', 'Ю', 'Я', 'а', 'б', 'в',
                 'г', 'д', 'е', 'ё', 'ж', 'з', 'и', 'й', 'к', 'л', 'м', 'н',
                 'о', 'п', 'р', 'с', 'т', 'у', 'ф', 'х', 'ц', 'ч', 'ш', 'щ',
                 'ъ', 'ы', 'ь', 'э', 'ю', 'я'];

    $lat = ['A', 'B', 'V', 'G', 'D', 'E', 'E', 'Gh', 'Z', 'I', 'Y', 'K',
                'L', 'M', 'N', 'O', 'P', 'R', 'S', 'T', 'U', 'F', 'H', 'C',
                'Ch', 'Sh', 'Sch', 'Y', 'Y', 'Y', 'E', 'Yu', 'Ya', 'a', 'b', 'v',
                'g', 'd', 'e', 'e', 'gh', 'z', 'i', 'y', 'k', 'l', 'm', 'n', 'o',
                'p', 'r', 's', 't', 'u', 'f', 'h', 'c', 'ch', 'sh', 'sch',
                'y', 'y', 'y', 'e', 'yu', 'ya'];

    $str = str_replace($rus, $lat, $str);

    return $str;

}
// Генератор пароля
function gen_pass($col = 6) {
    $mask = "0123456789AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz";
    $password = NULL;
    for ($i = 0; $i < $col; $i++)
        $password.= $mask[random_int(0, 61)];
    return $password;
}
// Иконка девайса
function deviceIcon($ua) {

    $detect = new Mobile_Detect;
    $detect->setUserAgent($ua);

    if ($detect->isTablet()) {
        // планшет
        $device = '<img src="/img/tablet.png" alt="tablet">';
    } elseif ($detect->isMobile()) {
        // телефон
        $device = '<img src="/img/phone.png" alt="phone">';
    } else {
        // пк
        $device = '<img src="/img/pc.png" alt="pc">';
    }

    return $device;

}
// Уровни пользователей
$admList = [

    'Пользователь',

    'Администратор',

    'Журналист газеты',

    'Модератор форума',

    'Tester'

];
// Узнаем id по логину
function uid($login) {

    global $connect;

    $strow = $connect->prepare("select * from `users` where `login` = ?");
    $strow->execute(array($login));
    $row = $strow->fetch(PDO::FETCH_LAZY);

    return $row['id'] ?? 0;

}
// Узнаем логин по id
function ulogin($uid) {

    global $connect;

    $strow = $connect->prepare("select * from `users` where `id` = ?");
    $strow->execute(array($uid));
    $row = $strow->fetch(PDO::FETCH_LAZY);

    return $row['login'] ?? false;

}
// Инфо о юзере
function user($user, $type = 0) {

    global $connect;

    $user = $type == 1 ? uid($user) : $user;

    $result = $connect->prepare("select * from `users` where `id` = ?");
    $result->execute(array($user));
    $row = $result->fetch(PDO::FETCH_LAZY);

    return $row ?? [];

}
// Инфо об авторизации юзера
function authlog($user, $type = 0) {

    global $connect;

    if (user($user, $type)) {

        $user = $type == 0 ? ulogin($user) : $user;

        $result = $connect->prepare("select * from `authlog` where `user` = ? order by `lasttime` desc");
        $result->execute(array($user));
        $row = $result->fetch(PDO::FETCH_LAZY);

    }

    return $row ?? [];

}
// Статус онлайн
function online($user, $type = 0) {

    $auth = authlog($user, $type);

    if ($auth && $auth['status'] == 1 && $auth['lasttime'] > time() - 300) {

        $online = deviceIcon($auth['ua']);

    }

    return $online ?? false;

}
// Иконка юзера
function iconUser($user, $type = 0) {

    $row = user($user, $type);

    if ($row) {

        if (file_exists($_SERVER["DOCUMENT_ROOT"]."/files/icon/".$row['icon']) && $row['icon']) {
           $img = '<img src="/files/icon/'.$row['icon'].'" alt="icon">';
        } else {
            if ($row['ban'] > time()) {
                $img = '<img src="/img/user/ban.png" alt="ban">'; 
            } else { 
                if ($row['admin'] == 1) {
                    $img = $row['pol'] == 1 ? '<img src="/img/user/admin-male.png" alt="admin-male">' : '<img src="/img/user/admin-female.png" alt="admin-female">';
                } else {
                    $img = $row['pol'] == 1 ? '<img src="/img/user/male.png" alt="male">' : '<img src="/img/user/female.png" alt="female">';
                }
            }
        }

    } else {
        $img = '<img src="/img/user/bot.png" alt="bot">';
    }

    return $img;

}
// Градиент ника
function gradient($user) {

    $row = user($user, 1);

    if ($row && $row['color1'] && $row['color2']) {

        $res = str2gradient($row['login'], $row['color1'], $row['color2']);

    }

    return $res ?? $user;

}
// Приватная почта
function p_mail_user($from, $to) {

    global $connect;

    $count = $connect->prepare("select count(*) from `friend` where `status` = '1' and `user_from` = :from and `user_to` = :to or `user_from` = :to and `user_to` = :from");

    $row = user($from, 1);

    if ($row) {

        if ($row['fmail'] == 1) {

            $result = 1;

        } else {

            $count->bindValue(':from', $from);
            $count->bindValue(':to', $to);
            $count->execute();

            if ($count->fetchColumn())
                $result = 1;

        }

    }

    return $result ?? 0;

}
// Создаем уведомления
function notification($text, $user, $type = 0) {

    global $connect;

    if (user($user, $type)) {

        $user = $type == 1 ? uid($user) : $user;

        $stmt = $connect->prepare("insert into `notifications` set `time` = ?, `uid` = ?, `text` = ?");
        $stmt->execute(array(time(), $user, $text));

    }
}
// Добавляем в контакты
function contact_add($from, $to) {

    global $connect;

    $count = $connect->prepare("select count(*) from `contacts` where `user_from` = :from and `user_to` = :to or `user_from` = :to and `user_to` = :from");
    $count->bindValue(':from', $from);
    $count->bindValue(':to', $to);
    $count->execute();

    if ($count->fetchColumn()) {
        $stmt = $connect->prepare("update `contacts` set `time` = :time where `user_from` = :from and `user_to` = :to or `user_from` = :to and `user_to` = :from");
        $stmt->execute(array(':time' => time(), ':from' => $from, ':to' => $to));
    } else {
        $stmt = $connect->prepare("insert into `contacts` set `time` = ?, `user_from` = ?, `user_to` = ?");
        $stmt->execute(array(time(), $from, $to));
    }
}
// Очки дружбы
function friendPoint($from, $to, $col = 1) {

    global $connect;

    $friend = $connect->prepare("select count(*) from `friend` where `status` = '1' and (`user_from` = :from and `user_to` = :to or `user_from` = :to and `user_to` = :from)");
    $friend->bindValue(':from', $from);
    $friend->bindValue(':to', $to);
    $friend->execute();

    if ($friend->fetchColumn()) {
        $point = $connect->prepare("update `friend` set `point` = `point` + :col where `user_from` = :from and `user_to` = :to or `user_from` = :to and `user_to` = :from");
        $point->execute(array(':col' => $col, ':from' => $from, ':to' => $to));
    }
}
// Рейтинг
function ratingUser($rating, $user, $type = 0) {

    global $connect;

    if (user($user, $type)) {

        $user = $type == 0 ? ulogin($user) : $user;

        $stmt = $connect->prepare("update `users` set `rating` = `rating` + ? where `login` = ?");
        $stmt->execute(array($rating, $user));

    }
}
// Звание
function rankUser($rating) {

    global $connect;

    $sql = $connect->query("select * from `rank` order by `rating` desc");

    foreach ($sql as $row) {
        if ($rating >= $row['rating']) {
            $rank = $row['rank']." | ".$rating;
            break;
        }
    }

    return $rank ?? $rating;

}
// Черный список
function in_blacklist($user, $black, $type = 0) {

    global $connect;

    if (user($user, $type) && user($black, $type)) {

        $user = $type == 0 ? ulogin($user) : $user;
        $black = $type == 0 ? ulogin($black) : $black;

        $black_r = $connect->prepare("select count(*) from `blacklist` where `user` = ? and `black` = ?");
        $black_r->execute(array($user, $black));

    }

    return $black_r->fetchColumn() ?? 0;

}

// Авторизация
if (isset($_COOKIE['login']) && isset($_COOKIE['pass']) && isset($_COOKIE['auth'])) {
    // проверяем авторизацию
    $authcheck = $connect->prepare("select count(*) from `authlog` where `status` = '1' and `user` = ? and `id` = ?");
    $authcheck->execute(array($_COOKIE['login'], $_COOKIE['auth']));
    // ищем юзера в базе
    $user = user($_COOKIE['login'], 1); 
    if ($user && $user['pass'] == $_COOKIE['pass'] && $authcheck->fetchColumn()) {
        // Юзер авторизован
        $active = 1;
        // Онлайн
        $authup = $connect->prepare("update `authlog` set `lasttime` = ? where `id` = ?");
        $authup->execute(array(time(), $_COOKIE['auth']));
        // Инфо об авторизации
        $user_auth = authlog($user['id']);
    } else {
        // сбрасываем куки
        session_destroy();
        setcookie('login', null, time() - 3600, '/');
        setcookie('pass', null, time() - 3600, '/');
        setcookie('auth', null, time() - 3600, '/');
    }
}

/* Чистка БД */

// Удаление старых сообщений чата
$stmt = $connect->prepare("delete from `guest` where `date` < :date");
$stmt->bindValue(':date', time() - 3600 * 24 * 25, PDO::PARAM_INT);
$stmt->execute();
// Очистка лога о пополнених
$stmt = $connect->prepare("delete from `plus` where `time` < :date");
$stmt->bindValue(':date', time() - 3600 * 24, PDO::PARAM_INT);
$stmt->execute();
// Очистка уведомлений
$stmt = $connect->prepare("delete from `notifications` where `new` = '0' and `time` < :date");
$stmt->bindValue(':date', time() - 3600 * 24 * 25, PDO::PARAM_INT);
$stmt->execute(); 
// Очистка лога о переходах
$stmt = $connect->prepare("delete from `click` where `time` < :time");
$stmt->bindValue(':time', mktime(0, 0, 1), PDO::PARAM_INT);
$stmt->execute();

/* prepared */

$authlog = $connect->prepare("insert into `authlog` set `time` = ?, `user` = ?, `ip` = ?, `ua` = ?");

/* Счетчики модулей */

// Speedpass
$count_sp = $connect->query("select count(*) from `speedpass`")->fetchColumn(); 

// Количество званий юзеров
$count_rank = $connect->query("select count(*) from `rank`")->fetchColumn();

// Кол-во заявок на вывод
$count_payment = $connect->query("select count(*) from `payment` where `status` = '0'")->fetchColumn();
$new_payment = $count_payment > 0 ? '<font color="#d8544f">+'.$count_payment.'</font>' : '';
$yes_payment = $connect->query("select count(*) from `payment` where `status` = '1'")->fetchColumn();
$no_payment = $connect->query("select count(*) from `payment` where `status` = '2'")->fetchColumn();
$all_payment = $count_payment + $yes_payment + $no_payment;
// Всего выплачено
$sum_payment = $connect->query("select sum(`money`) from `payment` where `status` = '1'")->fetchColumn() ?? 0;

// Кол-во новостей
$count_news = $connect->query("select  count(*) from `news`")->fetchColumn();
// Последние новости
$stmt_newss = $connect->prepare("select count(*) from `news` where `time` > :time");
$stmt_newss->bindValue(':time', mktime(0, 0, 1), PDO::PARAM_INT);
$stmt_newss->execute();
$c_newss = $stmt_newss->fetchColumn();
$newss = $c_newss > 0 ? '<span>+'.$c_newss.'</span>' : '';

// Кол-во пользователей
$count_users = $connect->query("select count(*) from `users`")->fetchColumn();
// Кол-во зарегистрированных пользователей сегодня
$stmt_users_new = $connect->prepare("select count(*) from `users` where `datereg` > :datereg");
$stmt_users_new->bindValue(':datereg', mktime(0, 0, 1), PDO::PARAM_INT);
$stmt_users_new->execute();
$count_users_new = $stmt_users_new->fetchColumn();
// Команда сайта
$count_team_user = $connect->query("select count(*) from `users` where `admin` != '0'")->fetchColumn();
// Кол-во заблокированных пользователей
$stmt_ban_user = $connect->prepare("select count(*) from `users` where `ban` > :time");
$stmt_ban_user->bindValue(':time', time(), PDO::PARAM_INT);
$stmt_ban_user->execute();
$count_ban_user = $stmt_ban_user->fetchColumn();
// Деньги у юзеров
$money_users = $connect->query("select sum(`money`) from `users` where `admin` != '1'")->fetchColumn() ?? 0;

// Кол-во пользователей онлайн
$stmt_online = $connect->prepare("select * from `authlog` where `status` = '1' and `lasttime` > :time group by `user`");
$stmt_online->bindValue(':time', time() - 300, PDO::PARAM_INT);
$stmt_online->execute();
$count_online_user = $stmt_online->rowCount();
// Заходило сегодня
$stmt_day = $connect->prepare("select * from `authlog` where `lasttime` > :time group by `user`");
$stmt_day->bindValue(':time', mktime(0, 0, 1), PDO::PARAM_INT);
$stmt_day->execute();
$count_day_user = $stmt_day->rowCount();

if ($mod_array['ads'] == 1) {
    // Реклама
    $rek = $connect->query("select count(*) from `rek`")->fetchColumn();
    // Активная реклама
    $stmt_rek = $connect->prepare("select count(*) from `rek` where `status` = '1' and `expire` > :time");
    $stmt_rek->bindValue(':time', time(), PDO::PARAM_INT);
    $stmt_rek->execute();
    $active_rek = $stmt_rek->fetchColumn();
    // на модерации
    $c_mod_rek = $connect->query("select count(*) from `rek` where `status` = '3'")->fetchColumn();
    $new_mod_rek = $c_mod_rek > 0 ? '<font color="#d8544f">+'.$c_mod_rek.'</font>' : '';
    if (isset($active)) {
        // последняя ссылка
        $stmt_lr = $connect->prepare("select * from `rek` where `status` = '1' and `expire` > :time order by `expire` asc");
        $stmt_lr->bindValue(':time', time(), PDO::PARAM_INT);
        $stmt_lr->execute();
        $last_rek = $stmt_lr->fetch(PDO::FETCH_LAZY);
        // реклама юзера
        $stmt_user_rek = $connect->prepare("select count(*) from `rek` where `user` = ?");
        $stmt_user_rek->execute(array($user['login']));
        $user_rek = $stmt_user_rek->fetchColumn();
    }
}

if ($mod_array['shop'] == 1) {

    // prepared
    $stmt_user_shop = $connect->prepare("select count(*) from `shop` where `user` = ?"); 

    // Продаж за сегодня
    $stmt_day_sell = $connect->prepare("select count(*) from `purchase` where `time` > :date");
     $stmt_day_sell->bindValue(':date', mktime(0, 0, 1), PDO::PARAM_INT);
     $stmt_day_sell->execute();
    $day_sell = $stmt_day_sell->fetchColumn();
    // на сумму
    $stmt_sum_day_sell = $connect->prepare("select sum(`sum`) from `purchase` where `time` > :date");
    $stmt_sum_day_sell->bindValue(':date', mktime(0, 0, 1), PDO::PARAM_INT);
    $stmt_sum_day_sell->execute();
    $sum_day_sell = $stmt_sum_day_sell->fetchColumn() ?? 0;
    // Продаж за все время
    $all_sell = $connect->query("select count(*) from `purchase`")->fetchColumn();
    // на сумму
    $sum_all_sell = $connect->query("select sum(`sum`) from `purchase`")->fetchColumn() ?? 0;
    // кол-во категорий
    $count_shop_kat = $connect->query("select count(*) from `kat` where `type` = '1'")->fetchColumn();
    // Кол-во товаров в магазине
    $count_shop = $connect->query("select count(*) from `shop` where `status` = '1'")->fetchColumn();
    // Кол-во товаров на модерации
    $c_mod_shop = $connect->query("select count(*) from `shop` where `status` = '0'")->fetchColumn();
    $new_mod_shop = $c_mod_shop > 0 ? '<font color="#d8544f">+'.$c_mod_shop.'</font>' : '';
    // все товары
    $all_shop = $count_shop + $c_mod_shop;
    // Новые товары
    $stmt_new_shop = $connect->prepare("select count(*) from `shop` where `status` = '1' and `time` > :time");
    $stmt_new_shop->bindValue(':time', mktime(0, 0, 1), PDO::PARAM_INT);
    $stmt_new_shop->execute();
    $c_new_shop = $stmt_new_shop->fetchColumn();
    $new_shop = $c_new_shop > 0 ? '<span>+'.$c_new_shop.'</span>' : '';
    // Последние обновления
    $last_update_shop = $connect->query("select count(*) from `shop` where `status` = '1' and `upd` != '0'")->fetchColumn(); 

    if (isset($active)) {

        // Кол-во товаров юзера
        $stmt_user_shop->execute(array($user['login']));
        $count_user_shop = $stmt_user_shop->fetchColumn();
        // покупки юзера
        $stmt_user_purch = $connect->prepare("select count(*) from `purchase` where `user` = ?");
        $stmt_user_purch->execute(array($user['login']));
        $user_purch = $stmt_user_purch->fetchColumn();
        // на сумму
        $stmt_sup = $connect->prepare("select sum(`sum`) from `purchase` where `user` = ?");
        $stmt_sup->execute(array($user['login']));
        $sum_user_purch = $stmt_sup->fetchColumn() ?? 0;
        // продажи юзера
        $stmt_user_kassa = $connect->prepare("select count(*) from `purchase` where `seller` = ?");
        $stmt_user_kassa->execute(array($user['login']));
        $user_kassa = $stmt_user_kassa->fetchColumn();
        // на сумму
        $stmt_suk = $connect->prepare("select sum(`sum`) from `purchase` where `seller` = ?");
        $stmt_suk->execute(array($user['login']));
        $sum_user_kassa = $stmt_suk->fetchColumn() ?? 0;
        // корзина
        $stmt_user_bk = $connect->prepare("select count(*) from `basket` where `user` = ?");
        $stmt_user_bk->execute(array($user['login']));
        $user_bk = $stmt_user_bk->fetchColumn();

        /* Обработка платежей магазина */

        $shop_time = time() - 3600 * 24 * $sys_array['sdays'];

        $data = $connect->prepare("select * from `purchase` where `status` = '0' and `time` < :time order by `id` limit 15");
        $data->bindValue(':time', $shop_time, PDO::PARAM_INT);
        $data->execute();
        $sql = $data->fetchAll();

        foreach ($sql as $row) {
            // Рейтинг
            ratingUser($rat_array['shop'], $row['seller'], 1);
            // Выплата
            $money = $connect->prepare("update `users` set `money` = `money` + ? where `login` = ?");
            $money->execute(array($row['sum'], $row['seller']));
            // Статус платежа
            $purchase = $connect->prepare("update `purchase` set `status` = '1' where `id` = ?");
            $purchase->execute(array($row['id']));
        }
    }
}

if (isset($active)) {

    // авторизации юзера
    $stmt_auth = $connect->prepare("select count(*) from `authlog` where `user` = ?");
    $stmt_auth->execute(array($user['login']));
    $count_auth = $stmt_auth->fetchColumn();

    // черный список
    $stmt_black = $connect->prepare("select count(*) from `blacklist` where `user` = ?");
    $stmt_black->execute(array($user['login']));
    $count_black = $stmt_black->fetchColumn();

    // уведомления
    $stmt_not = $connect->prepare("select count(*) from `notifications` where `uid` = ?");
    $stmt_not->execute(array($user['id']));
    $not = $stmt_not->fetchColumn();
    // Новые уведомления
    $stmt_new_not = $connect->prepare("select count(*) from `notifications` where `new` = '1' and `uid` = ?");
    $stmt_new_not->execute(array($user['id']));
    $c_new_not = $stmt_new_not->fetchColumn();
    $new_not = $c_new_not > 0 ? '<span>+'.$c_new_not.'</span>' : '';

    // друзья юзера
    $stmt_friends = $connect->prepare("select count(*) from `friend` where `status` = '1' and (`user_from` = :user or `user_to` = :user)");
    $stmt_friends->bindValue(':user', $user['login']);
    $stmt_friends->execute();
    $count_friends = $stmt_friends->fetchColumn();
    // заявки в друзья
    $stmt_req = $connect->prepare("select count(*) from `friend` where `status` = '0' and `user_to` = ?");
    $stmt_req->execute(array($user['login']));
    $count_req = $stmt_req->fetchColumn();
    $new_req = $count_req > 0 ? '<span>+'.$count_req.'</span>' : '';

    // Кол-во цепочек писем
    $stmt_mess = $connect->prepare("select count(*) from `contacts` where `user_from` = :user or `user_to` = :user");
    $stmt_mess->bindValue(':user', $user['login']);
    $stmt_mess->execute();
    $count_mess = $stmt_mess->fetchColumn();
    // Сообщения
    $count_mail = $connect->prepare("select count(*) from `mail` where `who` = :user or `user` = :user");
    $count_mail->bindValue(':user', $user['login']);
    $count_mail->execute();
    $count_mail = $count_mail->fetchColumn();
    $c_new_mail = $connect->prepare("select count(*) from `mail` where `read` = '0' and `who` = ?");
    $c_new_mail->execute(array($user['login']));
    $c_new_mail = $c_new_mail->fetchColumn();
    $new_mail = $c_new_mail > 0 ? '<span>+'.$c_new_mail.'</span>' : '';

    // Кол-во рефералов
    $stmt_ref = $connect->prepare("select count(*) from `users` where `ref` = ?");
    $stmt_ref->execute(array($user['id']));
    $count_ref = $stmt_ref->fetchColumn();

    // Кол-во сообщений чата
    $count_chat = $connect->query("select count(*) from `guest`")->fetchColumn();
    // Новые сообщения чата
    $stmt_new_chat = $connect->prepare("select count(*) from `guest` where `date` > :time");
    $stmt_new_chat->bindValue(':time', mktime(0, 0, 1), PDO::PARAM_INT);
    $stmt_new_chat->execute();
    $c_new_chat = $stmt_new_chat->fetchColumn();
    $new_chat = $c_new_chat > 0 ? '<span>+'.$c_new_chat.'</span>' : '';

    // Выплачено юзеру
    $stmt_user_payment = $connect->prepare("select sum(`money`) from `payment` where `status` = '1' and `user` = ?");
    $stmt_user_payment->execute(array($user['login']));
    $user_payment = $stmt_user_payment->fetchColumn() ?? 0;

    if ($mod_array['forum'] == 1) { 
        // Форум
        $count_forum = $connect->query("select count(*) from `topic`")->fetchColumn();
        // кол-во категорий
        $count_forum_kat = $connect->query("select count(*) from `kat` where `type` = '2'")->fetchColumn();
        // темы юзера
        $stmt_user_f = $connect->prepare("select count(*) from `topic` where `user` = ?");
        $stmt_user_f->execute(array($user['login']));
        $user_forum = $stmt_user_f->fetchColumn();
        // Кол-во постов
        $count_fp = $connect->query("select count(*) from `comments` where `type` = '3'")->fetchColumn();
        // Новые посты
        $stmt_new_fp = $connect->prepare("select count(*) from `comments` where `type` = '3' and`date` > :time");
        $stmt_new_fp->bindValue(':time', mktime(0, 0, 1), PDO::PARAM_INT);
        $stmt_new_fp->execute();
        $c_new_fp = $stmt_new_fp->fetchColumn();
        $new_fp = $c_new_fp > 0 ? '<span>+'.$c_new_fp.'</span>' : ''; 
    }

    if ($mod_array['serf'] == 1) {
        // Активные юзеры серфинга
        $active_users = $connect->query("select * from `click` group by `user`")->rowCount();
        // Общее кол-во площадок
        $all_links = $connect->query("select count(*) from `link`")->fetchColumn();
        $active_links = $connect->query("select count(*) from `link` where `click` > '0' and `off` = '0'")->fetchColumn();
        // На модерации
        $c_mod_link = $connect->query("select count(*) from `link` where `off` = '3'")->fetchColumn();
        $new_mod_link = $c_mod_link > 0 ? '<font color="#d8544f">+'.$c_mod_link.'</font>' : '';
        // Кол-во ссылок серфинга
        $count_serf = 0;
        $stmt_click = $connect->prepare("select count(*) from `click` where `user` = ? and `link` = ?");
        $data = $connect->prepare("select `id` from `link` where `click` > '0' and `user` != :user and `off` = '0'");
         $data->bindValue(':user', $user['login']);
        $data->execute(); 
        $sql = $data->fetchAll();
        foreach ($sql as $row) {
            $stmt_click->execute(array($user['login'], $row['id']));
            if (!$stmt_click->fetchColumn())
                $count_serf++;
        }
        // Кол-во площадок
        $stmt_link = $connect->prepare("select count(*) from `link` where `user` = ?");
        $stmt_link->execute(array($user['login']));
        $links = $stmt_link->fetchColumn();
        // Кол-во платных переходов
        $clicks = $connect->query("select count(*) from `click`")->fetchColumn();
    }

    if ($mod_array['task'] == 1) {
        // выполнено заданий
        $stmt_success_tasks = $connect->prepare("select count(*) from `task_ans` where `status` = '1' and `time` > :time");
        $stmt_success_tasks->bindValue(':time', mktime(0, 0, 1), PDO::PARAM_INT);
        $stmt_success_tasks->execute();
        $success_tasks = $stmt_success_tasks->fetchColumn();
        // активных пользователей в заданиях
        $stmt_at = $connect->prepare("select * from `task_ans` where `status` = '1' and `time` > :time group by `user`");
        $stmt_at->bindValue(':time', mktime(0, 0, 1), PDO::PARAM_INT);
        $stmt_at->execute();
        $active_task_users = $stmt_at->rowCount();
        // Кол-во заданий
        $stmt_tasks = $connect->prepare("select count(*) from `task` where `status` = '1' and `col` > '0' and `user` != ?");
        $stmt_tasks->execute(array($user['login']));
        $count_tasks = $stmt_tasks->fetchColumn();
        $all_tasks = $connect->query("select count(*) from `task`")->fetchColumn();
        // На модерации
        $c_mod_task = $connect->query("select count(*) from `task` where `status` = '3'")->fetchColumn();
        $new_mod_task = $c_mod_task > 0 ? '<font color="#d8544f">+'.$c_mod_task.'</font>' : '';
        // Кол-во заданий юзера
        $stmt_user_tasks = $connect->prepare("select count(*) from `task` where `user` = ?");
        $stmt_user_tasks->execute(array($user['login']));
        $count_user_tasks = $stmt_user_tasks->fetchColumn();
        // статистика выполнений
        $stmt_user_task = $connect->prepare("select count(*) from `task_ans` where `user` = ?");
        $stmt_user_task->execute(array($user['login']));
        $user_task_stat = $stmt_user_task->fetchColumn();
    }

    if ($mod_array['num'] == 1) {
        // Кол-во ставок в num
        $count_num = $connect->query("select count(*) from `num`")->fetchColumn();
    }

    if ($mod_array['loto'] == 1) {

        // Кол-во играющих в лотерею
        $loto_count = $connect->query("select count(*) from `loto`")->fetchColumn();
        // Кол-во победителей в лотерее
        $count_win_loto = $connect->query("select count(*) from `win_loto`")->fetchColumn();
        // Выигрыш
        $loto_cash = $sys_array['loto'] * $sys_array['loto_cena'];

        // Определение победителя
        if ($loto_count >= $sys_array['loto']) {
            $loto = $connect->query("select * from `loto` order by rand()")->fetch(PDO::FETCH_LAZY);
            $money = $connect->prepare("update  `users` set `money` = `money` + ? where `login` = ?");
            $log = $connect->prepare("insert into `win_loto` set `time` = ?, `user` = ?, `sum` = ?");
            if ($money->execute(array($loto_cash, $loto['user'])) && $log->execute(array(time(), $loto['user'], $loto_cash))) {
                notification('Вы победили в лотерее! Выигрыш - '.quantDec($loto_cash, ['рубль', 'рубля', 'рублей']), $loto['user'], 1);
                $connect->exec("delete from `loto`");
            }
        }
    }

    if ($mod_array['prmd'] == 1) {

        // Кол-во ставок в пирамиде
        $count_prmd = $connect->query("select count(*) from `prmd`")->fetchColumn();
        // выигрыш
        $prmd_cash = $connect->query("select sum(`sum`) from `prmd`")->fetchColumn() ?? 0;
        // Кол-во победителей в пирамиде
        $count_win_prmd = $connect->query("select count(*) from `win_prmd`")->fetchColumn();
        // Последняя ставка
        $row_prmd = $connect->query("select * from `prmd` order by `id` desc")->fetch(PDO::FETCH_LAZY);
        // Последний победитель
        $last_prmd = $connect->query("select * from `win_prmd` order by `id` desc")->fetch(PDO::FETCH_LAZY);

        // Определение победителя
        if ($count_prmd > 1 && $row_prmd['time'] < time() - 3600) {
            $money = $connect->prepare("update `users` set `money` = `money` + ? where `login` = ?");
            $log = $connect->prepare("insert into `win_prmd` set `time` = ?, `user` = ?, `sum` = ?");
            if ($money->execute(array($prmd_cash, $row_prmd['user'])) && $log->execute(array(time(), $row_prmd['user'], $prmd_cash))) {
                notification('Вы победили в пирамиде! Выигрыш - '.quantDec($prmd_cash, ['рубль', 'рубля', 'рублей']), $row_prmd['user'], 1);
                $connect->exec("delete from `prmd`");
            }
        }
    }

    // Счетчик для админа
    $counters_adm = $count_payment + ($c_mod_shop ?? 0) + ($c_mod_link ?? 0) + ($c_mod_task ?? 0) + ($c_mod_rek ?? 0);
    $new_adm = $counters_adm > 0 ? '<font color="#d8544f">+'.$counters_adm.'</font>' : ''; 

}
?>